# Copyright (c) 2013 Cloudera, Inc. All rights reserved.

from cmf.monitor.jmx_beans import JsonParserJmx

class JsonParser(JsonParserJmx):
  def __init__(self, json_dict):
    """
    May raise ParseError if the json structure is not what we expect.
    """
    JsonParserJmx.__init__(self, json_dict, 'NAVIGATOR')

#
# Update from CM's nightly-1 on 5/7/2013.
#
SAMPLE = r"""
{
  "beans" : [ {
    "name" : "java.lang:type=Memory",
    "modelerType" : "sun.management.MemoryImpl",
    "Verbose" : false,
    "HeapMemoryUsage" : {
      "committed" : 85000192,
      "init" : 0,
      "max" : 1065025536,
      "used" : 37039848
    },
    "NonHeapMemoryUsage" : {
      "committed" : 83763200,
      "init" : 24313856,
      "max" : 136314880,
      "used" : 52523888
    },
    "ObjectPendingFinalizationCount" : 0
  }, {
    "name" : "java.lang:type=GarbageCollector,name=ConcurrentMarkSweep",
    "modelerType" : "sun.management.GarbageCollectorImpl",
    "LastGcInfo" : null,
    "CollectionCount" : 2,
    "CollectionTime" : 0,
    "Name" : "ConcurrentMarkSweep",
    "Valid" : true,
    "MemoryPoolNames" : [ "Par Eden Space", "Par Survivor Space", "CMS Old Gen", "CMS Perm Gen" ]
  }, {
    "name" : "java.lang:type=Compilation",
    "modelerType" : "sun.management.CompilationImpl",
    "Name" : "HotSpot 64-Bit Tiered Compilers",
    "CompilationTimeMonitoringSupported" : true,
    "TotalCompilationTime" : 30228
  }, {
    "name" : "java.lang:type=MemoryPool,name=Par Eden Space",
    "modelerType" : "sun.management.MemoryPoolImpl",
    "Name" : "Par Eden Space",
    "Type" : "HEAP",
    "Valid" : true,
    "CollectionUsage" : {
      "committed" : 17432576,
      "init" : 17432576,
      "max" : 69795840,
      "used" : 0
    },
    "CollectionUsageThreshold" : 0,
    "CollectionUsageThresholdCount" : 0,
    "MemoryManagerNames" : [ "ConcurrentMarkSweep", "ParNew" ],
    "PeakUsage" : {
      "committed" : 17432576,
      "init" : 17432576,
      "max" : 69795840,
      "used" : 17432576
    },
    "Usage" : {
      "committed" : 17432576,
      "init" : 17432576,
      "max" : 69795840,
      "used" : 16833776
    },
    "CollectionUsageThresholdExceeded" : true,
    "CollectionUsageThresholdSupported" : true,
    "UsageThresholdSupported" : false
  }, {
    "name" : "com.cloudera.navigator.ipc:type=NavigatorIPC,name=insert-request",
    "modelerType" : "com.yammer.metrics.reporting.JmxReporter$Meter",
    "Count" : 29555,
    "EventType" : "requests",
    "RateUnit" : "SECONDS",
    "MeanRate" : 1.5837195623993372,
    "OneMinuteRate" : 1.7997989086604953,
    "FiveMinuteRate" : 1.789705643850417,
    "FifteenMinuteRate" : 1.672721830056058
  }, {
    "name" : "com.mchange.v2.c3p0:type=PooledDataSource[2sojge8uzabznew6dolq|73d4d493]",
    "modelerType" : "com.mchange.v2.c3p0.management.DynamicPooledDataSourceManagerMBean",
    "overrideDefaultPassword" : null,
    "statementCacheNumConnectionsWithCachedStatementsAllUsers" : 3,
    "dataSourceName" : "2sojge8uzabznew6dolq|73d4d493",
    "threadPoolNumIdleThreads" : 3,
    "acquireRetryAttempts" : 30,
    "autoCommitOnClose" : false,
    "identityToken" : "2sojge8uzabznew6dolq|73d4d493",
    "forceIgnoreUnresolvedTransactions" : false,
    "startTimeMillisDefaultUser" : 1367933272928,
    "breakAfterAcquireFailure" : false,
    "maxPoolSize" : 50,
    "idleConnectionTestPeriod" : 300,
    "user" : "navigatorb5b9455",
    "numIdleConnectionsDefaultUser" : 5,
    "numFailedCheckoutsDefaultUser" : 0,
    "numConnections" : 5,
    "numBusyConnections" : 0,
    "connectionCustomizerClassName" : null,
    "automaticTestTable" : null,
    "numFailedIdleTestsDefaultUser" : 0,
    "statementCacheNumStatementsDefaultUser" : 24,
    "effectivePropertyCycleDefaultUser" : 0.0,
    "maxIdleTime" : 0,
    "numConnectionsAllUsers" : 5,
    "numBusyConnectionsDefaultUser" : 0,
    "userOverrides" : "{}",
    "maxIdleTimeExcessConnections" : 0,
    "checkoutTimeout" : 0,
    "allUsers" : "[navigatorb5b9455]",
    "statementCacheNumConnectionsWithCachedStatementsDefaultUser" : 3,
    "usesTraditionalReflectiveProxies" : false,
    "maxAdministrativeTaskTime" : 0,
    "userOverridesAsString" : null,
    "driverClass" : null,
    "connectionTesterClassName" : "com.mchange.v2.c3p0.impl.DefaultConnectionTester",
    "maxStatements" : 2500,
    "statementCacheNumCheckedOutDefaultUser" : 0,
    "statementCacheNumStatementsAllUsers" : 24,
    "numUnclosedOrphanedConnectionsDefaultUser" : 0,
    "debugUnreturnedConnectionStackTraces" : false,
    "testConnectionOnCheckout" : false,
    "numConnectionsDefaultUser" : 5,
    "acquireRetryDelay" : 1000,
    "overrideDefaultUser" : null,
    "threadPoolNumTasksPending" : 0,
    "threadPoolSize" : 3,
    "unreturnedConnectionTimeout" : 0,
    "acquireIncrement" : 3,
    "numThreadsAwaitingCheckoutDefaultUser" : 0,
    "threadPoolNumActiveThreads" : 0,
    "minPoolSize" : 5,
    "maxStatementsPerConnection" : 0,
    "statementCacheNumCheckedOutStatementsAllUsers" : 0,
    "testConnectionOnCheckin" : false,
    "numUserPools" : 1,
    "numFailedCheckinsDefaultUser" : 0,
    "numUnclosedOrphanedConnectionsAllUsers" : 0,
    "initialPoolSize" : 3,
    "upTimeMillisDefaultUser" : 18681178,
    "numUnclosedOrphanedConnections" : 0,
    "loginTimeout" : 0,
    "numIdleConnectionsAllUsers" : 4,
    "maxConnectionAge" : 0,
    "factoryClassLocation" : null,
    "jdbcUrl" : "jdbc:mysql://nightly-1.ent.cloudera.com:3306/navigatorb5b94558b487d693a56b721a91aa2fa0?useUnicode=true&characterEncoding=UTF-8",
    "propertyCycle" : 0,
    "numBusyConnectionsAllUsers" : 1,
    "numIdleConnections" : 4,
    "numHelperThreads" : 3,
    "preferredTestQuery" : null,
    "description" : null
  }, {
    "name" : "java.lang:type=MemoryPool,name=CMS Perm Gen",
    "modelerType" : "sun.management.MemoryPoolImpl",
    "Name" : "CMS Perm Gen",
    "Type" : "NON_HEAP",
    "Valid" : true,
    "CollectionUsage" : {
      "committed" : 47513600,
      "init" : 21757952,
      "max" : 85983232,
      "used" : 46994184
    },
    "CollectionUsageThreshold" : 0,
    "CollectionUsageThresholdCount" : 0,
    "MemoryManagerNames" : [ "ConcurrentMarkSweep" ],
    "PeakUsage" : {
      "committed" : 78323712,
      "init" : 21757952,
      "max" : 85983232,
      "used" : 47334480
    },
    "Usage" : {
      "committed" : 78323712,
      "init" : 21757952,
      "max" : 85983232,
      "used" : 47334480
    },
    "UsageThreshold" : 0,
    "UsageThresholdCount" : 0,
    "CollectionUsageThresholdExceeded" : true,
    "CollectionUsageThresholdSupported" : true,
    "UsageThresholdExceeded" : true,
    "UsageThresholdSupported" : true
  }, {
    "name" : "java.lang:type=OperatingSystem",
    "modelerType" : "com.sun.management.UnixOperatingSystem",
    "MaxFileDescriptorCount" : 32768,
    "OpenFileDescriptorCount" : 269,
    "CommittedVirtualMemorySize" : 3555237888,
    "FreePhysicalMemorySize" : 3730714624,
    "FreeSwapSpaceSize" : 2097143808,
    "ProcessCpuTime" : 151180000000,
    "TotalPhysicalMemorySize" : 10371452928,
    "TotalSwapSpaceSize" : 2097143808,
    "Name" : "Linux",
    "Version" : "2.6.32-220.7.1.el6.x86_64",
    "AvailableProcessors" : 4,
    "Arch" : "amd64",
    "SystemLoadAverage" : 1.2
  }, {
    "name" : "java.lang:type=MemoryPool,name=Par Survivor Space",
    "modelerType" : "sun.management.MemoryPoolImpl",
    "Name" : "Par Survivor Space",
    "Type" : "HEAP",
    "Valid" : true,
    "CollectionUsage" : {
      "committed" : 2162688,
      "init" : 2162688,
      "max" : 8716288,
      "used" : 911880
    },
    "CollectionUsageThreshold" : 0,
    "CollectionUsageThresholdCount" : 0,
    "MemoryManagerNames" : [ "ConcurrentMarkSweep", "ParNew" ],
    "PeakUsage" : {
      "committed" : 2162688,
      "init" : 2162688,
      "max" : 8716288,
      "used" : 2162688
    },
    "Usage" : {
      "committed" : 2162688,
      "init" : 2162688,
      "max" : 8716288,
      "used" : 911880
    },
    "CollectionUsageThresholdExceeded" : true,
    "CollectionUsageThresholdSupported" : true,
    "UsageThresholdSupported" : false
  }, {
    "name" : "java.lang:type=MemoryManager,name=CodeCacheManager",
    "modelerType" : "sun.management.MemoryManagerImpl",
    "Name" : "CodeCacheManager",
    "Valid" : true,
    "MemoryPoolNames" : [ "Code Cache" ]
  }, {
    "name" : "com.cloudera.navigator:type=NavigatorCountersMXBean",
    "modelerType" : "com.cloudera.navigator.NavigatorCounters",
    "Version" : "5.0.0-SNAPSHOT (#17 built by jenkins on 20130506-1932 git: 141ce1d10be8a95ce6f7d586a4c62fa382a81fd8)",
    "CoalesceCount" : [ {
      "key" : "HBASE-2",
      "value" : 0
    }, {
      "key" : "HDFS-2",
      "value" : 6
    }, {
      "key" : "HUE-2",
      "value" : 0
    } ],
    "ParseErrorCount" : [ {
      "key" : "HBASE-2",
      "value" : 0
    }, {
      "key" : "HDFS-2",
      "value" : 0
    }, {
      "key" : "HUE-2",
      "value" : 0
    } ],
    "AuditFilterCount" : [ {
      "key" : "HBASE-2",
      "value" : 35
    }, {
      "key" : "HDFS-2",
      "value" : 2975
    }, {
      "key" : "HUE-2",
      "value" : 0
    } ],
    "PipelineExceptionCount" : [ {
      "key" : "HBASE-2",
      "value" : 0
    }, {
      "key" : "HDFS-2",
      "value" : 0
    }, {
      "key" : "HUE-2",
      "value" : 0
    } ],
    "QueueFullCount" : [ {
      "key" : "HBASE-2",
      "value" : 0
    }, {
      "key" : "HDFS-2",
      "value" : 0
    }, {
      "key" : "HUE-2",
      "value" : 0
    } ],
    "OneMinProductionRatesPerPlugin" : [ {
      "key" : "HDFS-2-NAMENODE-96844c141e3aa1b2c32b64ebd0abd57d",
      "value" : 0.008978516624524842
    }, {
      "key" : "HBASE-2-REGIONSERVER-12505f57b274711a7f993d38cd10fcda",
      "value" : 0.0
    }, {
      "key" : "HDFS-2-NAMENODE-12505f57b274711a7f993d38cd10fcda",
      "value" : 0.0
    }, {
      "key" : "HBASE-2-REGIONSERVER-12713042e574ad390285c71dec281017",
      "value" : 0.0
    }, {
      "key" : "HBASE-2-REGIONSERVER-31c05e07d3549f7a3bb5cbe971eec3da",
      "value" : 0.0
    }, {
      "key" : "HBASE-2-MASTER-96844c141e3aa1b2c32b64ebd0abd57d",
      "value" : 0.0
    }, {
      "key" : "HBASE-2-REGIONSERVER-96844c141e3aa1b2c32b64ebd0abd57d",
      "value" : 0.0
    } ],
    "FiveMinProductionRatesPerPlugin" : [ {
      "key" : "HDFS-2-NAMENODE-96844c141e3aa1b2c32b64ebd0abd57d",
      "value" : 0.014675951566358335
    }, {
      "key" : "HBASE-2-REGIONSERVER-12505f57b274711a7f993d38cd10fcda",
      "value" : 0.0
    }, {
      "key" : "HDFS-2-NAMENODE-12505f57b274711a7f993d38cd10fcda",
      "value" : 0.0
    }, {
      "key" : "HBASE-2-REGIONSERVER-12713042e574ad390285c71dec281017",
      "value" : 0.0
    }, {
      "key" : "HBASE-2-REGIONSERVER-31c05e07d3549f7a3bb5cbe971eec3da",
      "value" : 0.0
    }, {
      "key" : "HBASE-2-MASTER-96844c141e3aa1b2c32b64ebd0abd57d",
      "value" : 0.0
    }, {
      "key" : "HBASE-2-REGIONSERVER-96844c141e3aa1b2c32b64ebd0abd57d",
      "value" : 0.0
    } ],
    "FifteenMinProductionRatePerPlugin" : [ {
      "key" : "HDFS-2-NAMENODE-96844c141e3aa1b2c32b64ebd0abd57d",
      "value" : 0.008951895347890813
    }, {
      "key" : "HBASE-2-REGIONSERVER-12505f57b274711a7f993d38cd10fcda",
      "value" : 0.0
    }, {
      "key" : "HDFS-2-NAMENODE-12505f57b274711a7f993d38cd10fcda",
      "value" : 0.0
    }, {
      "key" : "HBASE-2-REGIONSERVER-12713042e574ad390285c71dec281017",
      "value" : 0.0
    }, {
      "key" : "HBASE-2-REGIONSERVER-31c05e07d3549f7a3bb5cbe971eec3da",
      "value" : 0.0
    }, {
      "key" : "HBASE-2-MASTER-96844c141e3aa1b2c32b64ebd0abd57d",
      "value" : 0.0
    }, {
      "key" : "HBASE-2-REGIONSERVER-96844c141e3aa1b2c32b64ebd0abd57d",
      "value" : 0.0
    } ],
    "OneMinConsumptionRatePerPlugin" : [ {
      "key" : "HDFS-2-NAMENODE-96844c141e3aa1b2c32b64ebd0abd57d",
      "value" : 0.009188421225056587
    }, {
      "key" : "HBASE-2-REGIONSERVER-12505f57b274711a7f993d38cd10fcda",
      "value" : 0.0
    }, {
      "key" : "HDFS-2-NAMENODE-12505f57b274711a7f993d38cd10fcda",
      "value" : 0.0
    }, {
      "key" : "HBASE-2-REGIONSERVER-12713042e574ad390285c71dec281017",
      "value" : 0.0
    }, {
      "key" : "HBASE-2-REGIONSERVER-31c05e07d3549f7a3bb5cbe971eec3da",
      "value" : 0.0
    }, {
      "key" : "HBASE-2-MASTER-96844c141e3aa1b2c32b64ebd0abd57d",
      "value" : 0.0
    }, {
      "key" : "HBASE-2-REGIONSERVER-96844c141e3aa1b2c32b64ebd0abd57d",
      "value" : 0.0
    } ],
    "FiveMinConsumptionRatePerPlugin" : [ {
      "key" : "HDFS-2-NAMENODE-96844c141e3aa1b2c32b64ebd0abd57d",
      "value" : 0.01474849115614972
    }, {
      "key" : "HBASE-2-REGIONSERVER-12505f57b274711a7f993d38cd10fcda",
      "value" : 0.0
    }, {
      "key" : "HDFS-2-NAMENODE-12505f57b274711a7f993d38cd10fcda",
      "value" : 0.0
    }, {
      "key" : "HBASE-2-REGIONSERVER-12713042e574ad390285c71dec281017",
      "value" : 0.0
    }, {
      "key" : "HBASE-2-REGIONSERVER-31c05e07d3549f7a3bb5cbe971eec3da",
      "value" : 0.0
    }, {
      "key" : "HBASE-2-MASTER-96844c141e3aa1b2c32b64ebd0abd57d",
      "value" : 0.0
    }, {
      "key" : "HBASE-2-REGIONSERVER-96844c141e3aa1b2c32b64ebd0abd57d",
      "value" : 0.0
    } ],
    "FifteenMinConsumptionRatePerPlugin" : [ {
      "key" : "HDFS-2-NAMENODE-96844c141e3aa1b2c32b64ebd0abd57d",
      "value" : 0.008969656106934886
    }, {
      "key" : "HBASE-2-REGIONSERVER-12505f57b274711a7f993d38cd10fcda",
      "value" : 0.0
    }, {
      "key" : "HDFS-2-NAMENODE-12505f57b274711a7f993d38cd10fcda",
      "value" : 0.0
    }, {
      "key" : "HBASE-2-REGIONSERVER-12713042e574ad390285c71dec281017",
      "value" : 0.0
    }, {
      "key" : "HBASE-2-REGIONSERVER-31c05e07d3549f7a3bb5cbe971eec3da",
      "value" : 0.0
    }, {
      "key" : "HBASE-2-MASTER-96844c141e3aa1b2c32b64ebd0abd57d",
      "value" : 0.0
    }, {
      "key" : "HBASE-2-REGIONSERVER-96844c141e3aa1b2c32b64ebd0abd57d",
      "value" : 0.0
    } ],
    "FailedRequestsCount" : [ {
      "key" : "HBASE-2",
      "value" : 5
    }, {
      "key" : "HDFS-2",
      "value" : 1
    }, {
      "key" : "HUE-2",
      "value" : 1
    } ]
  }, {
    "name" : "java.lang:type=MemoryPool,name=CMS Old Gen",
    "modelerType" : "sun.management.MemoryPoolImpl",
    "Name" : "CMS Old Gen",
    "Type" : "HEAP",
    "Valid" : true,
    "CollectionUsage" : {
      "committed" : 65404928,
      "init" : 65404928,
      "max" : 986513408,
      "used" : 7941384
    },
    "CollectionUsageThreshold" : 0,
    "CollectionUsageThresholdCount" : 0,
    "MemoryManagerNames" : [ "ConcurrentMarkSweep" ],
    "PeakUsage" : {
      "committed" : 65404928,
      "init" : 65404928,
      "max" : 986513408,
      "used" : 19294192
    },
    "Usage" : {
      "committed" : 65404928,
      "init" : 65404928,
      "max" : 986513408,
      "used" : 19294192
    },
    "UsageThreshold" : 0,
    "UsageThresholdCount" : 0,
    "CollectionUsageThresholdExceeded" : true,
    "CollectionUsageThresholdSupported" : true,
    "UsageThresholdExceeded" : true,
    "UsageThresholdSupported" : true
  }, {
    "name" : "java.lang:type=MemoryPool,name=Code Cache",
    "modelerType" : "sun.management.MemoryPoolImpl",
    "Name" : "Code Cache",
    "Type" : "NON_HEAP",
    "Valid" : true,
    "CollectionUsage" : null,
    "MemoryManagerNames" : [ "CodeCacheManager" ],
    "PeakUsage" : {
      "committed" : 5439488,
      "init" : 2555904,
      "max" : 50331648,
      "used" : 5221312
    },
    "Usage" : {
      "committed" : 5439488,
      "init" : 2555904,
      "max" : 50331648,
      "used" : 5210816
    },
    "UsageThreshold" : 0,
    "UsageThresholdCount" : 0,
    "CollectionUsageThresholdSupported" : false,
    "UsageThresholdExceeded" : true,
    "UsageThresholdSupported" : true
  }, {
    "name" : "java.lang:type=Runtime",
    "modelerType" : "sun.management.RuntimeImpl",
    "Name" : "14397@nightly-1.ent.cloudera.com",
    "ClassPath" : "/var/run/cloudera-scm-agent/process/152-cloudera-mgmt-NAVIGATOR:/usr/share/java/mysql-connector-java.jar:/usr/share/cmf/lib/cxf-rt-transports-common-2.5.5.jar:/usr/share/cmf/lib/avro-1.6.3.jar:/usr/share/cmf/lib/guava-14.0.jar:/usr/share/cmf/lib/jamonapi-2.73.jar:/usr/share/cmf/lib/byon-1.5.8.jar:/usr/share/cmf/lib/mvel2-2.1.3.Final.jar:/usr/share/cmf/lib/spring-security-ldap-3.1.0.RELEASE.jar:/usr/share/cmf/lib/xpp3_min-1.1.4c.jar:/usr/share/cmf/lib/openstack-nova-ec2-1.5.8.jar:/usr/share/cmf/lib/cloudstack-1.5.8.jar:/usr/share/cmf/lib/jsp-2.1-glassfish-2.1.v20091210.jar:/usr/share/cmf/lib/cloudservers-1.5.8.jar:/usr/share/cmf/lib/jaxb-api-2.2.3.jar:/usr/share/cmf/lib/skalicloud-sdg-my-1.5.8.jar:/usr/share/cmf/lib/joda-money-0.6.jar:/usr/share/cmf/lib/quartz-2.0.2.jar:/usr/share/cmf/lib/commons-httpclient-3.1.jar:/usr/share/cmf/lib/cloudera-manager-api-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/jackson-xc-1.8.11.jar:/usr/share/cmf/lib/hibernate-ehcache-4.1.4.Final.jar:/usr/share/cmf/lib/greenhousedata-element-vcloud-1.5.8.jar:/usr/share/cmf/lib/commons-codec-1.4.jar:/usr/share/cmf/lib/spring-jdbc-3.0.6.RELEASE.jar:/usr/share/cmf/lib/common-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/ninefold-compute-1.5.8.jar:/usr/share/cmf/lib/jsr305-2.0.1.jar:/usr/share/cmf/lib/headlamp-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/commons-management-1.0.jar:/usr/share/cmf/lib/commons-beanutils-core-1.8.3.jar:/usr/share/cmf/lib/xz-1.2.jar:/usr/share/cmf/lib/cxf-rt-core-2.5.5.jar:/usr/share/cmf/lib/lucene-core-3.1.0.jar:/usr/share/cmf/lib/commons-collections-3.2.1.jar:/usr/share/cmf/lib/xstream-1.3.1.jar:/usr/share/cmf/lib/elastichosts-lon-b-1.5.8.jar:/usr/share/cmf/lib/go2cloud-jhb1-1.5.8.jar:/usr/share/cmf/lib/camel-spring-2.7.2.jar:/usr/share/cmf/lib/hibernate-c3p0-4.1.4.Final.jar:/usr/share/cmf/lib/slf4j-log4j12-1.6.1.jar:/usr/share/cmf/lib/dom4j-1.6.1.jar:/usr/share/cmf/lib/jclouds-scriptbuilder-1.5.8.jar:/usr/share/cmf/lib/cxf-rt-frontend-jaxrs-2.5.5.jar:/usr/share/cmf/lib/camel-core-2.7.2.jar:/usr/share/cmf/lib/mx4j-tools-3.0.1.jar:/usr/share/cmf/lib/chive-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/commons-dbutils-1.4.jar:/usr/share/cmf/lib/jopt-simple-3.2.jar:/usr/share/cmf/lib/spring-tx-3.0.6.RELEASE.jar:/usr/share/cmf/lib/rimuhosting-1.5.8.jar:/usr/share/cmf/lib/wsdl4j-1.6.2.jar:/usr/share/cmf/lib/slf4j-api-1.6.1.jar:/usr/share/cmf/lib/spring-security-core-3.1.0.RELEASE.jar:/usr/share/cmf/lib/geronimo-stax-api_1.0_spec-1.0.1.jar:/usr/share/cmf/lib/jamon-api-2.3.0.jar:/usr/share/cmf/lib/hibernate-core-4.1.4.Final.jar:/usr/share/cmf/lib/cxf-rt-bindings-xml-2.5.5.jar:/usr/share/cmf/lib/spring-context-support-3.0.6.RELEASE.jar:/usr/share/cmf/lib/jackson-core-asl-1.8.11.jar:/usr/share/cmf/lib/event-common-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/server-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/usertype.core-3.0.0.CR1.jar:/usr/share/cmf/lib/cdh-client-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/async-http-client-1.7.5.jar:/usr/share/cmf/lib/jetty-sslengine-6.1.26.cloudera.2.jar:/usr/share/cmf/lib/trmk-vcloudexpress-1.5.8.jar:/usr/share/cmf/lib/trystack-nova-1.5.8.jar:/usr/share/cmf/lib/spring-security-config-3.1.0.RELEASE.jar:/usr/share/cmf/lib/antlr-2.7.7.jar:/usr/share/cmf/lib/spring-aop-3.0.6.RELEASE.jar:/usr/share/cmf/lib/hue-plugins-2.1.0-cdh4.1.0.jar:/usr/share/cmf/lib/javax.inject-1.jar:/usr/share/cmf/lib/hibernate-commons-annotations-4.0.1.Final.jar:/usr/share/cmf/lib/jackson-jaxrs-1.8.11.jar:/usr/share/cmf/lib/jsr250-api-1.0.jar:/usr/share/cmf/lib/openstack-nova-1.5.8.jar:/usr/share/cmf/lib/commons-io-2.0.1.jar:/usr/share/cmf/lib/hibernate-jpa-2.0-api-1.0.1.Final.jar:/usr/share/cmf/lib/jackson-jaxrs-json-provider-2.0.4.jar:/usr/share/cmf/lib/firehose-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/guice-assistedinject-3.0.jar:/usr/share/cmf/lib/event-query-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/persist-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/jetty-management-6.1.26.cloudera.2.jar:/usr/share/cmf/lib/ant-1.6.5.jar:/usr/share/cmf/lib/jackson-mapper-asl-1.8.11.jar:/usr/share/cmf/lib/elasticstack-1.5.8.jar:/usr/share/cmf/lib/libthrift-0.7.0.jar:/usr/share/cmf/lib/commons-fileupload-1.2.2.jar:/usr/share/cmf/lib/jclouds-core-1.5.8.jar:/usr/share/cmf/lib/jettison-1.3.2.jar:/usr/share/cmf/lib/tsquery-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/jsp-api-2.1-glassfish-2.1.v20091210.jar:/usr/share/cmf/lib/spring-webmvc-3.0.6.RELEASE.jar:/usr/share/cmf/lib/jetty-continuation-7.5.4.v20111024.jar:/usr/share/cmf/lib/firehose-client-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/sqlite-jdbc-3.7.2.jar:/usr/share/cmf/lib/antlr-runtime-3.3.jar:/usr/share/cmf/lib/mx4j-3.0.1.jar:/usr/share/cmf/lib/knowledge-api-5.5.0.Final.jar:/usr/share/cmf/lib/jackson-dataformat-csv-2.0.4.jar:/usr/share/cmf/lib/jetty-util-7.5.4.v20111024.jar:/usr/share/cmf/lib/snappy-java-1.0.4.1.jar:/usr/share/cmf/lib/spring-core-3.0.6.RELEASE.jar:/usr/share/cmf/lib/spring-asm-3.0.6.RELEASE.jar:/usr/share/cmf/lib/woodstox-core-asl-4.1.4.jar:/usr/share/cmf/lib/cxf-rt-transports-http-2.5.5.jar:/usr/share/cmf/lib/cloudsigma-1.5.8.jar:/usr/share/cmf/lib/jackson-core-2.0.4.jar:/usr/share/cmf/lib/paranamer-2.3.jar:/usr/share/cmf/lib/aopalliance-1.0.jar:/usr/share/cmf/lib/mysql-connector-java.jar:/usr/share/cmf/lib/knowledge-internal-api-5.5.0.Final.jar:/usr/share/cmf/lib/jetty-security-7.5.4.v20111024.jar:/usr/share/cmf/lib/jackson-databind-2.0.4.jar:/usr/share/cmf/lib/sqltool-2.2.8.jar:/usr/share/cmf/lib/elastichosts-lon-p-1.5.8.jar:/usr/share/cmf/lib/syssql-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/cxf-bundle-jaxrs-2.5.5.jar:/usr/share/cmf/lib/joda-time-2.1.jar:/usr/share/cmf/lib/spring-context-3.0.6.RELEASE.jar:/usr/share/cmf/lib/jdbcdslog-1.0.6.jar:/usr/share/cmf/lib/hpcloud-compute-1.5.8.jar:/usr/share/cmf/lib/commons-lang-2.6.jar:/usr/share/cmf/lib/rackspace-cloudservers-uk-1.5.8.jar:/usr/share/cmf/lib/elastichosts-sat-p-1.5.8.jar:/usr/share/cmf/lib/model-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/spring-ldap-core-1.3.1.RELEASE.jar:/usr/share/cmf/lib/commons-digester-1.8.jar:/usr/share/cmf/lib/usertype.spi-3.0.0.CR1.jar:/usr/share/cmf/lib/slicehost-1.5.8.jar:/usr/share/cmf/lib/commons-compress-1.5.jar:/usr/share/cmf/lib/jackson-annotations-2.0.4.jar:/usr/share/cmf/lib/aws-common-1.5.8.jar:/usr/share/cmf/lib/cloudsigma-lvs-1.5.8.jar:/usr/share/cmf/lib/nova-1.5.8.jar:/usr/share/cmf/lib/aws-ec2-1.5.8.jar:/usr/share/cmf/lib/httpclient-4.1.1.jar:/usr/share/cmf/lib/eucalyptus-partnercloud-ec2-1.5.8.jar:/usr/share/cmf/lib/openstack-keystone-1.5.8.jar:/usr/share/cmf/lib/stratogen-vcloud-mycloud-1.5.8.jar:/usr/share/cmf/lib/scm-client-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/jaxb-impl-2.2.4-1.jar:/usr/share/cmf/lib/c3p0-0.9.1.1.jar:/usr/share/cmf/lib/openstack-common-1.5.8.jar:/usr/share/cmf/lib/poi-3.7.jar:/usr/share/cmf/lib/spring-expression-3.0.6.RELEASE.jar:/usr/share/cmf/lib/jetty-6.1.26.cloudera.2.jar:/usr/share/cmf/lib/mail-1.4.3.jar:/usr/share/cmf/lib/jta-1.1.jar:/usr/share/cmf/lib/jboss-logging-3.1.0.GA.jar:/usr/share/cmf/lib/drools-templates-5.5.0.Final.jar:/usr/share/cmf/lib/alertpublisher-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/snakeyaml-1.10.jar:/usr/share/cmf/lib/trmk-ecloud-1.5.8.jar:/usr/share/cmf/lib/netty-3.4.6.Final.jar:/usr/share/cmf/lib/flume-ng-configuration-1.2.0.jar:/usr/share/cmf/lib/asm-3.1.jar:/usr/share/cmf/lib/inspector-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/commons-math-2.2.jar:/usr/share/cmf/lib/softlayer-1.5.8.jar:/usr/share/cmf/lib/navigator-plugin-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/jetty-util-6.1.26.cloudera.2.jar:/usr/share/cmf/lib/ecj-3.5.1.jar:/usr/share/cmf/lib/agent-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/serverlove-z1-man-1.5.8.jar:/usr/share/cmf/lib/jython-standalone-2.5.3.jar:/usr/share/cmf/lib/avro-ipc-1.6.3.jar:/usr/share/cmf/lib/hsqldb-2.2.8.jar:/usr/share/cmf/lib/stax2-api-3.1.1.jar:/usr/share/cmf/lib/velocity-1.7.jar:/usr/share/cmf/lib/jackson-datatype-joda-2.0.4.jar:/usr/share/cmf/lib/eventcatcher-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/jetty-http-7.5.4.v20111024.jar:/usr/share/cmf/lib/commons-logging-1.1.1.jar:/usr/share/cmf/lib/commons-cli-1.3-cloudera-pre-r1439998.jar:/usr/share/cmf/lib/jclouds-allcompute-1.5.8.jar:/usr/share/cmf/lib/spring-beans-3.0.6.RELEASE.jar:/usr/share/cmf/lib/servlet-api-2.5.jar:/usr/share/cmf/lib/javassist-3.15.0-GA.jar:/usr/share/cmf/lib/java-xmlbuilder-0.4.jar:/usr/share/cmf/lib/stringtemplate-3.2.1.jar:/usr/share/cmf/lib/rackspace-cloudservers-us-1.5.8.jar:/usr/share/cmf/lib/descriptors-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/commons-configuration-1.6.jar:/usr/share/cmf/lib/bluelock-vcloud-zone01-1.5.8.jar:/usr/share/cmf/lib/gogrid-1.5.8.jar:/usr/share/cmf/lib/flume-ng-sdk-1.2.0.jar:/usr/share/cmf/lib/jackson-module-jaxb-annotations-2.0.4.jar:/usr/share/cmf/lib/spring-security-crypto-3.1.0.RELEASE.jar:/usr/share/cmf/lib/jamon-processor-2.4.1.jar:/usr/share/cmf/lib/cxf-common-utilities-2.5.5.jar:/usr/share/cmf/lib/jsp-2.1-jetty-6.1.26.cloudera.2.jar:/usr/share/cmf/lib/cloudservers-us-1.5.8.jar:/usr/share/cmf/lib/protocol-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/sshj-0.8.0.jar:/usr/share/cmf/lib/vcloud-1.5.8.jar:/usr/share/cmf/lib/httpcore-4.1.jar:/usr/share/cmf/lib/log4j-1.2.16.jar:/usr/share/cmf/lib/spring-web-3.0.6.RELEASE.jar:/usr/share/cmf/lib/bcpg-jdk16-1.46.jar:/usr/share/cmf/lib/alfredo-0.1.4.jar:/usr/share/cmf/lib/antlr-3.3.jar:/usr/share/cmf/lib/cxf-api-2.5.5.jar:/usr/share/cmf/lib/camel-mail-2.7.2.jar:/usr/share/cmf/lib/event-publish-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/jetty-io-7.5.4.v20111024.jar:/usr/share/cmf/lib/rocoto-6.1.jar:/usr/share/cmf/lib/navigator-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/snmp4j-1.11.3.jar:/usr/share/cmf/lib/commons-beanutils-1.8.3.jar:/usr/share/cmf/lib/jamon-runtime-2.4.0.jar:/usr/share/cmf/lib/rackspace-cloudidentity-1.5.8.jar:/usr/share/cmf/lib/snmp4j-agent-1.3.1.jar:/usr/share/cmf/lib/gson-2.2.jar:/usr/share/cmf/lib/neethi-3.0.2.jar:/usr/share/cmf/lib/spring-security-web-3.1.0.RELEASE.jar:/usr/share/cmf/lib/ini4j-0.5.1.jar:/usr/share/cmf/lib/metrics-core-2.1.3.jar:/usr/share/cmf/lib/ec2-1.5.8.jar:/usr/share/cmf/lib/postgresql-9.0-801.jdbc4.jar:/usr/share/cmf/lib/guice-3.0.jar:/usr/share/cmf/lib/drools-compiler-5.5.0.Final.jar:/usr/share/cmf/lib/eucalyptus-1.5.8.jar:/usr/share/cmf/lib/trmk-common-1.5.8.jar:/usr/share/cmf/lib/bcprov-jdk16-1.46.jar:/usr/share/cmf/lib/jclouds-compute-1.5.8.jar:/usr/share/cmf/lib/xmlschema-core-2.0.3.jar:/usr/share/cmf/lib/openhosting-east1-1.5.8.jar:/usr/share/cmf/lib/activation-1.1.1.jar:/usr/share/cmf/lib/cloudsigma-zrh-1.5.8.jar:/usr/share/cmf/lib/hibernate-entitymanager-4.1.4.Final.jar:/usr/share/cmf/lib/drools-core-5.5.0.Final.jar:/usr/share/cmf/lib/jsr311-api-1.1.1.jar:/usr/share/cmf/lib/cloudservers-uk-1.5.8.jar:/usr/share/cmf/lib/deltacloud-1.5.8.jar:/usr/share/cmf/lib/ehcache-core-2.4.3.jar:/usr/share/cmf/lib/cglib-2.2.jar",
    "StartTime" : 1367933265659,
    "BootClassPath" : "/usr/java/jdk1.6.0_31/jre/lib/resources.jar:/usr/java/jdk1.6.0_31/jre/lib/rt.jar:/usr/java/jdk1.6.0_31/jre/lib/sunrsasign.jar:/usr/java/jdk1.6.0_31/jre/lib/jsse.jar:/usr/java/jdk1.6.0_31/jre/lib/jce.jar:/usr/java/jdk1.6.0_31/jre/lib/charsets.jar:/usr/java/jdk1.6.0_31/jre/lib/modules/jdk.boot.jar:/usr/java/jdk1.6.0_31/jre/classes",
    "LibraryPath" : "/usr/java/jdk1.6.0_31/jre/lib/amd64/server:/usr/java/jdk1.6.0_31/jre/lib/amd64:/usr/java/jdk1.6.0_31/jre/../lib/amd64:/usr/java/packages/lib/amd64:/usr/lib64:/lib64:/lib:/usr/lib",
    "VmName" : "Java HotSpot(TM) 64-Bit Server VM",
    "VmVendor" : "Sun Microsystems Inc.",
    "VmVersion" : "20.6-b01",
    "BootClassPathSupported" : true,
    "InputArguments" : [ "-XX:+UseConcMarkSweepGC", "-XX:-CMSConcurrentMTEnabled", "-XX:+UseParNewGC", "-Dmgmt.log.file=mgmt-cmf-MGMT-1-NAVIGATOR-nightly-1.ent.cloudera.com.log.out", "-Djava.awt.headless=true", "-Djava.net.preferIPv4Stack=true", "-Dnavigator.schema.dir=/usr/share/cmf/schema", "-Xmx1073741824" ],
    "ManagementSpecVersion" : "1.2",
    "SpecName" : "Java Virtual Machine Specification",
    "SpecVendor" : "Sun Microsystems Inc.",
    "SpecVersion" : "1.0",
    "SystemProperties" : [ {
      "key" : "java.ext.dirs",
      "value" : "/usr/java/jdk1.6.0_31/jre/lib/ext:/usr/java/packages/lib/ext"
    }, {
      "key" : "java.vm.specification.vendor",
      "value" : "Sun Microsystems Inc."
    }, {
      "key" : "user.timezone",
      "value" : "America/Los_Angeles"
    }, {
      "key" : "java.vm.vendor",
      "value" : "Sun Microsystems Inc."
    }, {
      "key" : "user.name",
      "value" : "cloudera-scm"
    }, {
      "key" : "java.vm.specification.name",
      "value" : "Java Virtual Machine Specification"
    }, {
      "key" : "user.dir",
      "value" : "/var/run/cloudera-scm-agent/process/152-cloudera-mgmt-NAVIGATOR"
    }, {
      "key" : "user.country",
      "value" : "US"
    }, {
      "key" : "user.language",
      "value" : "en"
    }, {
      "key" : "java.specification.version",
      "value" : "1.6"
    }, {
      "key" : "sun.cpu.endian",
      "value" : "little"
    }, {
      "key" : "java.home",
      "value" : "/usr/java/jdk1.6.0_31/jre"
    }, {
      "key" : "java.net.preferIPv4Stack",
      "value" : "true"
    }, {
      "key" : "sun.jnu.encoding",
      "value" : "UTF-8"
    }, {
      "key" : "file.separator",
      "value" : "/"
    }, {
      "key" : "java.vendor.url",
      "value" : "http://java.sun.com/"
    }, {
      "key" : "java.awt.graphicsenv",
      "value" : "sun.awt.X11GraphicsEnvironment"
    }, {
      "key" : "os.arch",
      "value" : "amd64"
    }, {
      "key" : "sun.nio.ch.bugLevel",
      "value" : ""
    }, {
      "key" : "java.io.tmpdir",
      "value" : "/tmp"
    }, {
      "key" : "java.runtime.name",
      "value" : "Java(TM) SE Runtime Environment"
    }, {
      "key" : "java.awt.printerjob",
      "value" : "sun.print.PSPrinterJob"
    }, {
      "key" : "file.encoding",
      "value" : "UTF-8"
    }, {
      "key" : "java.version",
      "value" : "1.6.0_31"
    }, {
      "key" : "java.vendor.url.bug",
      "value" : "http://java.sun.com/cgi-bin/bugreport.cgi"
    }, {
      "key" : "java.vm.specification.version",
      "value" : "1.0"
    }, {
      "key" : "file.encoding.pkg",
      "value" : "sun.io"
    }, {
      "key" : "navigator.schema.dir",
      "value" : "/usr/share/cmf/schema"
    }, {
      "key" : "sun.java.command",
      "value" : "com.cloudera.navigator.NavigatorMain --conf-dir /var/run/cloudera-scm-agent/process/152-cloudera-mgmt-NAVIGATOR"
    }, {
      "key" : "sun.java.launcher",
      "value" : "SUN_STANDARD"
    }, {
      "key" : "path.separator",
      "value" : ":"
    }, {
      "key" : "java.runtime.version",
      "value" : "1.6.0_31-b04"
    }, {
      "key" : "java.class.path",
      "value" : "/var/run/cloudera-scm-agent/process/152-cloudera-mgmt-NAVIGATOR:/usr/share/java/mysql-connector-java.jar:/usr/share/cmf/lib/cxf-rt-transports-common-2.5.5.jar:/usr/share/cmf/lib/avro-1.6.3.jar:/usr/share/cmf/lib/guava-14.0.jar:/usr/share/cmf/lib/jamonapi-2.73.jar:/usr/share/cmf/lib/byon-1.5.8.jar:/usr/share/cmf/lib/mvel2-2.1.3.Final.jar:/usr/share/cmf/lib/spring-security-ldap-3.1.0.RELEASE.jar:/usr/share/cmf/lib/xpp3_min-1.1.4c.jar:/usr/share/cmf/lib/openstack-nova-ec2-1.5.8.jar:/usr/share/cmf/lib/cloudstack-1.5.8.jar:/usr/share/cmf/lib/jsp-2.1-glassfish-2.1.v20091210.jar:/usr/share/cmf/lib/cloudservers-1.5.8.jar:/usr/share/cmf/lib/jaxb-api-2.2.3.jar:/usr/share/cmf/lib/skalicloud-sdg-my-1.5.8.jar:/usr/share/cmf/lib/joda-money-0.6.jar:/usr/share/cmf/lib/quartz-2.0.2.jar:/usr/share/cmf/lib/commons-httpclient-3.1.jar:/usr/share/cmf/lib/cloudera-manager-api-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/jackson-xc-1.8.11.jar:/usr/share/cmf/lib/hibernate-ehcache-4.1.4.Final.jar:/usr/share/cmf/lib/greenhousedata-element-vcloud-1.5.8.jar:/usr/share/cmf/lib/commons-codec-1.4.jar:/usr/share/cmf/lib/spring-jdbc-3.0.6.RELEASE.jar:/usr/share/cmf/lib/common-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/ninefold-compute-1.5.8.jar:/usr/share/cmf/lib/jsr305-2.0.1.jar:/usr/share/cmf/lib/headlamp-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/commons-management-1.0.jar:/usr/share/cmf/lib/commons-beanutils-core-1.8.3.jar:/usr/share/cmf/lib/xz-1.2.jar:/usr/share/cmf/lib/cxf-rt-core-2.5.5.jar:/usr/share/cmf/lib/lucene-core-3.1.0.jar:/usr/share/cmf/lib/commons-collections-3.2.1.jar:/usr/share/cmf/lib/xstream-1.3.1.jar:/usr/share/cmf/lib/elastichosts-lon-b-1.5.8.jar:/usr/share/cmf/lib/go2cloud-jhb1-1.5.8.jar:/usr/share/cmf/lib/camel-spring-2.7.2.jar:/usr/share/cmf/lib/hibernate-c3p0-4.1.4.Final.jar:/usr/share/cmf/lib/slf4j-log4j12-1.6.1.jar:/usr/share/cmf/lib/dom4j-1.6.1.jar:/usr/share/cmf/lib/jclouds-scriptbuilder-1.5.8.jar:/usr/share/cmf/lib/cxf-rt-frontend-jaxrs-2.5.5.jar:/usr/share/cmf/lib/camel-core-2.7.2.jar:/usr/share/cmf/lib/mx4j-tools-3.0.1.jar:/usr/share/cmf/lib/chive-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/commons-dbutils-1.4.jar:/usr/share/cmf/lib/jopt-simple-3.2.jar:/usr/share/cmf/lib/spring-tx-3.0.6.RELEASE.jar:/usr/share/cmf/lib/rimuhosting-1.5.8.jar:/usr/share/cmf/lib/wsdl4j-1.6.2.jar:/usr/share/cmf/lib/slf4j-api-1.6.1.jar:/usr/share/cmf/lib/spring-security-core-3.1.0.RELEASE.jar:/usr/share/cmf/lib/geronimo-stax-api_1.0_spec-1.0.1.jar:/usr/share/cmf/lib/jamon-api-2.3.0.jar:/usr/share/cmf/lib/hibernate-core-4.1.4.Final.jar:/usr/share/cmf/lib/cxf-rt-bindings-xml-2.5.5.jar:/usr/share/cmf/lib/spring-context-support-3.0.6.RELEASE.jar:/usr/share/cmf/lib/jackson-core-asl-1.8.11.jar:/usr/share/cmf/lib/event-common-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/server-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/usertype.core-3.0.0.CR1.jar:/usr/share/cmf/lib/cdh-client-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/async-http-client-1.7.5.jar:/usr/share/cmf/lib/jetty-sslengine-6.1.26.cloudera.2.jar:/usr/share/cmf/lib/trmk-vcloudexpress-1.5.8.jar:/usr/share/cmf/lib/trystack-nova-1.5.8.jar:/usr/share/cmf/lib/spring-security-config-3.1.0.RELEASE.jar:/usr/share/cmf/lib/antlr-2.7.7.jar:/usr/share/cmf/lib/spring-aop-3.0.6.RELEASE.jar:/usr/share/cmf/lib/hue-plugins-2.1.0-cdh4.1.0.jar:/usr/share/cmf/lib/javax.inject-1.jar:/usr/share/cmf/lib/hibernate-commons-annotations-4.0.1.Final.jar:/usr/share/cmf/lib/jackson-jaxrs-1.8.11.jar:/usr/share/cmf/lib/jsr250-api-1.0.jar:/usr/share/cmf/lib/openstack-nova-1.5.8.jar:/usr/share/cmf/lib/commons-io-2.0.1.jar:/usr/share/cmf/lib/hibernate-jpa-2.0-api-1.0.1.Final.jar:/usr/share/cmf/lib/jackson-jaxrs-json-provider-2.0.4.jar:/usr/share/cmf/lib/firehose-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/guice-assistedinject-3.0.jar:/usr/share/cmf/lib/event-query-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/persist-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/jetty-management-6.1.26.cloudera.2.jar:/usr/share/cmf/lib/ant-1.6.5.jar:/usr/share/cmf/lib/jackson-mapper-asl-1.8.11.jar:/usr/share/cmf/lib/elasticstack-1.5.8.jar:/usr/share/cmf/lib/libthrift-0.7.0.jar:/usr/share/cmf/lib/commons-fileupload-1.2.2.jar:/usr/share/cmf/lib/jclouds-core-1.5.8.jar:/usr/share/cmf/lib/jettison-1.3.2.jar:/usr/share/cmf/lib/tsquery-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/jsp-api-2.1-glassfish-2.1.v20091210.jar:/usr/share/cmf/lib/spring-webmvc-3.0.6.RELEASE.jar:/usr/share/cmf/lib/jetty-continuation-7.5.4.v20111024.jar:/usr/share/cmf/lib/firehose-client-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/sqlite-jdbc-3.7.2.jar:/usr/share/cmf/lib/antlr-runtime-3.3.jar:/usr/share/cmf/lib/mx4j-3.0.1.jar:/usr/share/cmf/lib/knowledge-api-5.5.0.Final.jar:/usr/share/cmf/lib/jackson-dataformat-csv-2.0.4.jar:/usr/share/cmf/lib/jetty-util-7.5.4.v20111024.jar:/usr/share/cmf/lib/snappy-java-1.0.4.1.jar:/usr/share/cmf/lib/spring-core-3.0.6.RELEASE.jar:/usr/share/cmf/lib/spring-asm-3.0.6.RELEASE.jar:/usr/share/cmf/lib/woodstox-core-asl-4.1.4.jar:/usr/share/cmf/lib/cxf-rt-transports-http-2.5.5.jar:/usr/share/cmf/lib/cloudsigma-1.5.8.jar:/usr/share/cmf/lib/jackson-core-2.0.4.jar:/usr/share/cmf/lib/paranamer-2.3.jar:/usr/share/cmf/lib/aopalliance-1.0.jar:/usr/share/cmf/lib/mysql-connector-java.jar:/usr/share/cmf/lib/knowledge-internal-api-5.5.0.Final.jar:/usr/share/cmf/lib/jetty-security-7.5.4.v20111024.jar:/usr/share/cmf/lib/jackson-databind-2.0.4.jar:/usr/share/cmf/lib/sqltool-2.2.8.jar:/usr/share/cmf/lib/elastichosts-lon-p-1.5.8.jar:/usr/share/cmf/lib/syssql-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/cxf-bundle-jaxrs-2.5.5.jar:/usr/share/cmf/lib/joda-time-2.1.jar:/usr/share/cmf/lib/spring-context-3.0.6.RELEASE.jar:/usr/share/cmf/lib/jdbcdslog-1.0.6.jar:/usr/share/cmf/lib/hpcloud-compute-1.5.8.jar:/usr/share/cmf/lib/commons-lang-2.6.jar:/usr/share/cmf/lib/rackspace-cloudservers-uk-1.5.8.jar:/usr/share/cmf/lib/elastichosts-sat-p-1.5.8.jar:/usr/share/cmf/lib/model-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/spring-ldap-core-1.3.1.RELEASE.jar:/usr/share/cmf/lib/commons-digester-1.8.jar:/usr/share/cmf/lib/usertype.spi-3.0.0.CR1.jar:/usr/share/cmf/lib/slicehost-1.5.8.jar:/usr/share/cmf/lib/commons-compress-1.5.jar:/usr/share/cmf/lib/jackson-annotations-2.0.4.jar:/usr/share/cmf/lib/aws-common-1.5.8.jar:/usr/share/cmf/lib/cloudsigma-lvs-1.5.8.jar:/usr/share/cmf/lib/nova-1.5.8.jar:/usr/share/cmf/lib/aws-ec2-1.5.8.jar:/usr/share/cmf/lib/httpclient-4.1.1.jar:/usr/share/cmf/lib/eucalyptus-partnercloud-ec2-1.5.8.jar:/usr/share/cmf/lib/openstack-keystone-1.5.8.jar:/usr/share/cmf/lib/stratogen-vcloud-mycloud-1.5.8.jar:/usr/share/cmf/lib/scm-client-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/jaxb-impl-2.2.4-1.jar:/usr/share/cmf/lib/c3p0-0.9.1.1.jar:/usr/share/cmf/lib/openstack-common-1.5.8.jar:/usr/share/cmf/lib/poi-3.7.jar:/usr/share/cmf/lib/spring-expression-3.0.6.RELEASE.jar:/usr/share/cmf/lib/jetty-6.1.26.cloudera.2.jar:/usr/share/cmf/lib/mail-1.4.3.jar:/usr/share/cmf/lib/jta-1.1.jar:/usr/share/cmf/lib/jboss-logging-3.1.0.GA.jar:/usr/share/cmf/lib/drools-templates-5.5.0.Final.jar:/usr/share/cmf/lib/alertpublisher-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/snakeyaml-1.10.jar:/usr/share/cmf/lib/trmk-ecloud-1.5.8.jar:/usr/share/cmf/lib/netty-3.4.6.Final.jar:/usr/share/cmf/lib/flume-ng-configuration-1.2.0.jar:/usr/share/cmf/lib/asm-3.1.jar:/usr/share/cmf/lib/inspector-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/commons-math-2.2.jar:/usr/share/cmf/lib/softlayer-1.5.8.jar:/usr/share/cmf/lib/navigator-plugin-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/jetty-util-6.1.26.cloudera.2.jar:/usr/share/cmf/lib/ecj-3.5.1.jar:/usr/share/cmf/lib/agent-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/serverlove-z1-man-1.5.8.jar:/usr/share/cmf/lib/jython-standalone-2.5.3.jar:/usr/share/cmf/lib/avro-ipc-1.6.3.jar:/usr/share/cmf/lib/hsqldb-2.2.8.jar:/usr/share/cmf/lib/stax2-api-3.1.1.jar:/usr/share/cmf/lib/velocity-1.7.jar:/usr/share/cmf/lib/jackson-datatype-joda-2.0.4.jar:/usr/share/cmf/lib/eventcatcher-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/jetty-http-7.5.4.v20111024.jar:/usr/share/cmf/lib/commons-logging-1.1.1.jar:/usr/share/cmf/lib/commons-cli-1.3-cloudera-pre-r1439998.jar:/usr/share/cmf/lib/jclouds-allcompute-1.5.8.jar:/usr/share/cmf/lib/spring-beans-3.0.6.RELEASE.jar:/usr/share/cmf/lib/servlet-api-2.5.jar:/usr/share/cmf/lib/javassist-3.15.0-GA.jar:/usr/share/cmf/lib/java-xmlbuilder-0.4.jar:/usr/share/cmf/lib/stringtemplate-3.2.1.jar:/usr/share/cmf/lib/rackspace-cloudservers-us-1.5.8.jar:/usr/share/cmf/lib/descriptors-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/commons-configuration-1.6.jar:/usr/share/cmf/lib/bluelock-vcloud-zone01-1.5.8.jar:/usr/share/cmf/lib/gogrid-1.5.8.jar:/usr/share/cmf/lib/flume-ng-sdk-1.2.0.jar:/usr/share/cmf/lib/jackson-module-jaxb-annotations-2.0.4.jar:/usr/share/cmf/lib/spring-security-crypto-3.1.0.RELEASE.jar:/usr/share/cmf/lib/jamon-processor-2.4.1.jar:/usr/share/cmf/lib/cxf-common-utilities-2.5.5.jar:/usr/share/cmf/lib/jsp-2.1-jetty-6.1.26.cloudera.2.jar:/usr/share/cmf/lib/cloudservers-us-1.5.8.jar:/usr/share/cmf/lib/protocol-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/sshj-0.8.0.jar:/usr/share/cmf/lib/vcloud-1.5.8.jar:/usr/share/cmf/lib/httpcore-4.1.jar:/usr/share/cmf/lib/log4j-1.2.16.jar:/usr/share/cmf/lib/spring-web-3.0.6.RELEASE.jar:/usr/share/cmf/lib/bcpg-jdk16-1.46.jar:/usr/share/cmf/lib/alfredo-0.1.4.jar:/usr/share/cmf/lib/antlr-3.3.jar:/usr/share/cmf/lib/cxf-api-2.5.5.jar:/usr/share/cmf/lib/camel-mail-2.7.2.jar:/usr/share/cmf/lib/event-publish-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/jetty-io-7.5.4.v20111024.jar:/usr/share/cmf/lib/rocoto-6.1.jar:/usr/share/cmf/lib/navigator-5.0.0-SNAPSHOT.jar:/usr/share/cmf/lib/snmp4j-1.11.3.jar:/usr/share/cmf/lib/commons-beanutils-1.8.3.jar:/usr/share/cmf/lib/jamon-runtime-2.4.0.jar:/usr/share/cmf/lib/rackspace-cloudidentity-1.5.8.jar:/usr/share/cmf/lib/snmp4j-agent-1.3.1.jar:/usr/share/cmf/lib/gson-2.2.jar:/usr/share/cmf/lib/neethi-3.0.2.jar:/usr/share/cmf/lib/spring-security-web-3.1.0.RELEASE.jar:/usr/share/cmf/lib/ini4j-0.5.1.jar:/usr/share/cmf/lib/metrics-core-2.1.3.jar:/usr/share/cmf/lib/ec2-1.5.8.jar:/usr/share/cmf/lib/postgresql-9.0-801.jdbc4.jar:/usr/share/cmf/lib/guice-3.0.jar:/usr/share/cmf/lib/drools-compiler-5.5.0.Final.jar:/usr/share/cmf/lib/eucalyptus-1.5.8.jar:/usr/share/cmf/lib/trmk-common-1.5.8.jar:/usr/share/cmf/lib/bcprov-jdk16-1.46.jar:/usr/share/cmf/lib/jclouds-compute-1.5.8.jar:/usr/share/cmf/lib/xmlschema-core-2.0.3.jar:/usr/share/cmf/lib/openhosting-east1-1.5.8.jar:/usr/share/cmf/lib/activation-1.1.1.jar:/usr/share/cmf/lib/cloudsigma-zrh-1.5.8.jar:/usr/share/cmf/lib/hibernate-entitymanager-4.1.4.Final.jar:/usr/share/cmf/lib/drools-core-5.5.0.Final.jar:/usr/share/cmf/lib/jsr311-api-1.1.1.jar:/usr/share/cmf/lib/cloudservers-uk-1.5.8.jar:/usr/share/cmf/lib/deltacloud-1.5.8.jar:/usr/share/cmf/lib/ehcache-core-2.4.3.jar:/usr/share/cmf/lib/cglib-2.2.jar"
    }, {
      "key" : "os.name",
      "value" : "Linux"
    }, {
      "key" : "mgmt.log.file",
      "value" : "mgmt-cmf-MGMT-1-NAVIGATOR-nightly-1.ent.cloudera.com.log.out"
    }, {
      "key" : "line.separator",
      "value" : "\n"
    }, {
      "key" : "os.version",
      "value" : "2.6.32-220.7.1.el6.x86_64"
    }, {
      "key" : "net.sf.ehcache.skipUpdateCheck",
      "value" : "true"
    }, {
      "key" : "sun.arch.data.model",
      "value" : "64"
    }, {
      "key" : "java.class.version",
      "value" : "50.0"
    }, {
      "key" : "sun.io.unicode.encoding",
      "value" : "UnicodeLittle"
    }, {
      "key" : "java.vendor",
      "value" : "Sun Microsystems Inc."
    }, {
      "key" : "sun.boot.class.path",
      "value" : "/usr/java/jdk1.6.0_31/jre/lib/resources.jar:/usr/java/jdk1.6.0_31/jre/lib/rt.jar:/usr/java/jdk1.6.0_31/jre/lib/sunrsasign.jar:/usr/java/jdk1.6.0_31/jre/lib/jsse.jar:/usr/java/jdk1.6.0_31/jre/lib/jce.jar:/usr/java/jdk1.6.0_31/jre/lib/charsets.jar:/usr/java/jdk1.6.0_31/jre/lib/modules/jdk.boot.jar:/usr/java/jdk1.6.0_31/jre/classes"
    }, {
      "key" : "java.awt.headless",
      "value" : "true"
    }, {
      "key" : "java.vm.info",
      "value" : "mixed mode"
    }, {
      "key" : "java.specification.name",
      "value" : "Java Platform API Specification"
    }, {
      "key" : "java.vm.name",
      "value" : "Java HotSpot(TM) 64-Bit Server VM"
    }, {
      "key" : "java.vm.version",
      "value" : "20.6-b01"
    }, {
      "key" : "sun.boot.library.path",
      "value" : "/usr/java/jdk1.6.0_31/jre/lib/amd64"
    }, {
      "key" : "java.endorsed.dirs",
      "value" : "/usr/java/jdk1.6.0_31/jre/lib/endorsed"
    }, {
      "key" : "sun.os.patch.level",
      "value" : "unknown"
    }, {
      "key" : "sun.cpu.isalist",
      "value" : ""
    }, {
      "key" : "user.home",
      "value" : "/var/run/cloudera-scm-server"
    }, {
      "key" : "java.library.path",
      "value" : "/usr/java/jdk1.6.0_31/jre/lib/amd64/server:/usr/java/jdk1.6.0_31/jre/lib/amd64:/usr/java/jdk1.6.0_31/jre/../lib/amd64:/usr/java/packages/lib/amd64:/usr/lib64:/lib64:/lib:/usr/lib"
    }, {
      "key" : "java.specification.vendor",
      "value" : "Sun Microsystems Inc."
    }, {
      "key" : "sun.management.compiler",
      "value" : "HotSpot 64-Bit Tiered Compilers"
    } ],
    "Uptime" : 18688472
  }, {
    "name" : "com.cloudera.navigator.ipc:type=NavigatorIPC,name=active-read-requests",
    "modelerType" : "com.yammer.metrics.reporting.JmxReporter$Counter",
    "Count" : 0
  }, {
    "name" : "java.lang:type=ClassLoading",
    "modelerType" : "sun.management.ClassLoadingImpl",
    "LoadedClassCount" : 5990,
    "UnloadedClassCount" : 10,
    "TotalLoadedClassCount" : 6000,
    "Verbose" : false
  }, {
    "name" : "java.lang:type=Threading",
    "modelerType" : "sun.management.ThreadImpl",
    "ThreadAllocatedMemoryEnabled" : true,
    "ThreadAllocatedMemorySupported" : true,
    "DaemonThreadCount" : 29,
    "PeakThreadCount" : 32,
    "CurrentThreadCpuTimeSupported" : true,
    "ObjectMonitorUsageSupported" : true,
    "SynchronizerUsageSupported" : true,
    "ThreadContentionMonitoringEnabled" : false,
    "ThreadContentionMonitoringSupported" : true,
    "ThreadCpuTimeEnabled" : true,
    "AllThreadIds" : [ 681, 678, 676, 670, 667, 666, 31, 30, 29, 28, 27, 26, 25, 23, 22, 20, 19, 18, 17, 16, 15, 14, 13, 12, 11, 10, 5, 3, 2, 1 ],
    "CurrentThreadCpuTime" : 90000000,
    "CurrentThreadUserTime" : 90000000,
    "ThreadCount" : 30,
    "TotalStartedThreadCount" : 674,
    "ThreadCpuTimeSupported" : true
  }, {
    "name" : "com.cloudera.navigator.ipc:type=NavigatorIPC,name=read-request",
    "modelerType" : "com.yammer.metrics.reporting.JmxReporter$Meter",
    "Count" : 11,
    "EventType" : "requests",
    "RateUnit" : "SECONDS",
    "MeanRate" : 5.894395297513006E-4,
    "OneMinuteRate" : 1.8368120605857056E-5,
    "FiveMinuteRate" : 0.004413614553603383,
    "FifteenMinuteRate" : 0.004874508147111546
  }, {
    "name" : "java.util.logging:type=Logging",
    "modelerType" : "java.util.logging.Logging",
    "LoggerNames" : [ "org.jboss.netty.channel.socket.nio.DefaultNioSocketChannelConfig", "org.jboss.netty.channel.DefaultChannelFuture", "org.jboss.netty.channel.socket.nio.NioClientSocketPipelineSink", "org.jboss.netty.util.ThreadRenamingRunnable", "org.jboss.netty.channel.socket.nio.AbstractNioWorker", "javax.management", "com.google.common.collect.MapMakerInternalMap", "org.jboss.netty.channel.CompleteChannelFuture", "org.jboss.netty.util.internal.QueueFactory", "sun.awt.AppContext", "org.jboss.netty.channel.socket.nio.SelectorUtil", "org.jboss.netty.channel.DefaultChannelPipeline", "global", "org.jboss.netty.channel.socket.nio.NioProviderMetadata", "org.jboss.netty.channel.SimpleChannelUpstreamHandler", "javax.management.mbeanserver", "org.jboss.netty.channel.socket.nio.NioClientSocketChannel", "" ]
  }, {
    "name" : "java.lang:type=GarbageCollector,name=ParNew",
    "modelerType" : "sun.management.GarbageCollectorImpl",
    "LastGcInfo" : {
      "GcThreadCount" : 5,
      "duration" : 5,
      "endTime" : 18627508,
      "id" : 219,
      "memoryUsageAfterGc" : [ {
        "key" : "CMS Perm Gen",
        "value" : {
          "committed" : 78323712,
          "init" : 21757952,
          "max" : 85983232,
          "used" : 47272696
        }
      }, {
        "key" : "Code Cache",
        "value" : {
          "committed" : 5439488,
          "init" : 2555904,
          "max" : 50331648,
          "used" : 5187968
        }
      }, {
        "key" : "CMS Old Gen",
        "value" : {
          "committed" : 65404928,
          "init" : 65404928,
          "max" : 986513408,
          "used" : 19294192
        }
      }, {
        "key" : "Par Eden Space",
        "value" : {
          "committed" : 17432576,
          "init" : 17432576,
          "max" : 69795840,
          "used" : 0
        }
      }, {
        "key" : "Par Survivor Space",
        "value" : {
          "committed" : 2162688,
          "init" : 2162688,
          "max" : 8716288,
          "used" : 911880
        }
      } ],
      "memoryUsageBeforeGc" : [ {
        "key" : "CMS Perm Gen",
        "value" : {
          "committed" : 78323712,
          "init" : 21757952,
          "max" : 85983232,
          "used" : 47272696
        }
      }, {
        "key" : "Code Cache",
        "value" : {
          "committed" : 5439488,
          "init" : 2555904,
          "max" : 50331648,
          "used" : 5187968
        }
      }, {
        "key" : "CMS Old Gen",
        "value" : {
          "committed" : 65404928,
          "init" : 65404928,
          "max" : 986513408,
          "used" : 19196272
        }
      }, {
        "key" : "Par Eden Space",
        "value" : {
          "committed" : 17432576,
          "init" : 17432576,
          "max" : 69795840,
          "used" : 17153456
        }
      }, {
        "key" : "Par Survivor Space",
        "value" : {
          "committed" : 2162688,
          "init" : 2162688,
          "max" : 8716288,
          "used" : 863688
        }
      } ],
      "startTime" : 18627503
    },
    "CollectionCount" : 219,
    "CollectionTime" : 1098,
    "Name" : "ParNew",
    "Valid" : true,
    "MemoryPoolNames" : [ "Par Eden Space", "Par Survivor Space" ]
  }, {
    "name" : "com.mchange.v2.c3p0:type=C3P0Registry",
    "modelerType" : "com.mchange.v2.c3p0.management.C3P0RegistryManager",
    "NumPooledDataSources" : 1,
    "NumPoolsAllDataSources" : 1,
    "AllIdentityTokens" : [ "2sojge8uzabznew6dolq|6b96bac4", "2sojge8uzabznew6dolq|73d4d493", "2sojge8uzabznew6dolq|578b1f8f" ],
    "AllIdentityTokenized" : "[com.mchange.v2.c3p0.DriverManagerDataSource@55ae6650 [ description -> null, driverClass -> null, factoryClassLocation -> null, identityToken -> 2sojge8uzabznew6dolq|578b1f8f, jdbcUrl -> jdbc:mysql://nightly-1.ent.cloudera.com:3306/navigatorb5b94558b487d693a56b721a91aa2fa0?useUnicode=true&characterEncoding=UTF-8, properties -> {user=******, password=******, autocommit=true, release_mode=auto} ], com.mchange.v2.c3p0.PoolBackedDataSource@10e18449 [ connectionPoolDataSource -> com.mchange.v2.c3p0.WrapperConnectionPoolDataSource@bc23ea6 [ acquireIncrement -> 3, acquireRetryAttempts -> 30, acquireRetryDelay -> 1000, autoCommitOnClose -> false, automaticTestTable -> null, breakAfterAcquireFailure -> false, checkoutTimeout -> 0, connectionCustomizerClassName -> null, connectionTesterClassName -> com.mchange.v2.c3p0.impl.DefaultConnectionTester, debugUnreturnedConnectionStackTraces -> false, factoryClassLocation -> null, forceIgnoreUnresolvedTransactions -> false, identityToken -> 2sojge8uzabznew6dolq|6b96bac4, idleConnectionTestPeriod -> 300, initialPoolSize -> 3, maxAdministrativeTaskTime -> 0, maxConnectionAge -> 0, maxIdleTime -> 0, maxIdleTimeExcessConnections -> 0, maxPoolSize -> 50, maxStatements -> 2500, maxStatementsPerConnection -> 0, minPoolSize -> 5, nestedDataSource -> com.mchange.v2.c3p0.DriverManagerDataSource@55ae6650 [ description -> null, driverClass -> null, factoryClassLocation -> null, identityToken -> 2sojge8uzabznew6dolq|578b1f8f, jdbcUrl -> jdbc:mysql://nightly-1.ent.cloudera.com:3306/navigatorb5b94558b487d693a56b721a91aa2fa0?useUnicode=true&characterEncoding=UTF-8, properties -> {user=******, password=******, autocommit=true, release_mode=auto} ], preferredTestQuery -> null, propertyCycle -> 0, testConnectionOnCheckin -> false, testConnectionOnCheckout -> false, unreturnedConnectionTimeout -> 0, usesTraditionalReflectiveProxies -> false; userOverrides: {} ], dataSourceName -> null, factoryClassLocation -> null, identityToken -> 2sojge8uzabznew6dolq|73d4d493, numHelperThreads -> 3 ], com.mchange.v2.c3p0.WrapperConnectionPoolDataSource@bc23ea6 [ acquireIncrement -> 3, acquireRetryAttempts -> 30, acquireRetryDelay -> 1000, autoCommitOnClose -> false, automaticTestTable -> null, breakAfterAcquireFailure -> false, checkoutTimeout -> 0, connectionCustomizerClassName -> null, connectionTesterClassName -> com.mchange.v2.c3p0.impl.DefaultConnectionTester, debugUnreturnedConnectionStackTraces -> false, factoryClassLocation -> null, forceIgnoreUnresolvedTransactions -> false, identityToken -> 2sojge8uzabznew6dolq|6b96bac4, idleConnectionTestPeriod -> 300, initialPoolSize -> 3, maxAdministrativeTaskTime -> 0, maxConnectionAge -> 0, maxIdleTime -> 0, maxIdleTimeExcessConnections -> 0, maxPoolSize -> 50, maxStatements -> 2500, maxStatementsPerConnection -> 0, minPoolSize -> 5, nestedDataSource -> com.mchange.v2.c3p0.DriverManagerDataSource@55ae6650 [ description -> null, driverClass -> null, factoryClassLocation -> null, identityToken -> 2sojge8uzabznew6dolq|578b1f8f, jdbcUrl -> jdbc:mysql://nightly-1.ent.cloudera.com:3306/navigatorb5b94558b487d693a56b721a91aa2fa0?useUnicode=true&characterEncoding=UTF-8, properties -> {user=******, password=******, autocommit=true, release_mode=auto} ], preferredTestQuery -> null, propertyCycle -> 0, testConnectionOnCheckin -> false, testConnectionOnCheckout -> false, unreturnedConnectionTimeout -> 0, usesTraditionalReflectiveProxies -> false; userOverrides: {} ]]",
    "AllPooledDataSources" : "[com.mchange.v2.c3p0.PoolBackedDataSource@10e18449 [ connectionPoolDataSource -> com.mchange.v2.c3p0.WrapperConnectionPoolDataSource@bc23ea6 [ acquireIncrement -> 3, acquireRetryAttempts -> 30, acquireRetryDelay -> 1000, autoCommitOnClose -> false, automaticTestTable -> null, breakAfterAcquireFailure -> false, checkoutTimeout -> 0, connectionCustomizerClassName -> null, connectionTesterClassName -> com.mchange.v2.c3p0.impl.DefaultConnectionTester, debugUnreturnedConnectionStackTraces -> false, factoryClassLocation -> null, forceIgnoreUnresolvedTransactions -> false, identityToken -> 2sojge8uzabznew6dolq|6b96bac4, idleConnectionTestPeriod -> 300, initialPoolSize -> 3, maxAdministrativeTaskTime -> 0, maxConnectionAge -> 0, maxIdleTime -> 0, maxIdleTimeExcessConnections -> 0, maxPoolSize -> 50, maxStatements -> 2500, maxStatementsPerConnection -> 0, minPoolSize -> 5, nestedDataSource -> com.mchange.v2.c3p0.DriverManagerDataSource@55ae6650 [ description -> null, driverClass -> null, factoryClassLocation -> null, identityToken -> 2sojge8uzabznew6dolq|578b1f8f, jdbcUrl -> jdbc:mysql://nightly-1.ent.cloudera.com:3306/navigatorb5b94558b487d693a56b721a91aa2fa0?useUnicode=true&characterEncoding=UTF-8, properties -> {user=******, password=******, autocommit=true, release_mode=auto} ], preferredTestQuery -> null, propertyCycle -> 0, testConnectionOnCheckin -> false, testConnectionOnCheckout -> false, unreturnedConnectionTimeout -> 0, usesTraditionalReflectiveProxies -> false; userOverrides: {} ], dataSourceName -> null, factoryClassLocation -> null, identityToken -> 2sojge8uzabznew6dolq|73d4d493, numHelperThreads -> 3 ]]",
    "AllIdentityTokenCount" : 3,
    "AllIdentityTokenizedCount" : 3,
    "AllPooledDataSourcesCount" : 1,
    "AllIdentityTokenizedStringified" : [ "com.mchange.v2.c3p0.DriverManagerDataSource@55ae6650 [ description -> null, driverClass -> null, factoryClassLocation -> null, identityToken -> 2sojge8uzabznew6dolq|578b1f8f, jdbcUrl -> jdbc:mysql://nightly-1.ent.cloudera.com:3306/navigatorb5b94558b487d693a56b721a91aa2fa0?useUnicode=true&characterEncoding=UTF-8, properties -> {user=******, password=******, autocommit=true, release_mode=auto} ]", "com.mchange.v2.c3p0.PoolBackedDataSource@10e18449 [ connectionPoolDataSource -> com.mchange.v2.c3p0.WrapperConnectionPoolDataSource@bc23ea6 [ acquireIncrement -> 3, acquireRetryAttempts -> 30, acquireRetryDelay -> 1000, autoCommitOnClose -> false, automaticTestTable -> null, breakAfterAcquireFailure -> false, checkoutTimeout -> 0, connectionCustomizerClassName -> null, connectionTesterClassName -> com.mchange.v2.c3p0.impl.DefaultConnectionTester, debugUnreturnedConnectionStackTraces -> false, factoryClassLocation -> null, forceIgnoreUnresolvedTransactions -> false, identityToken -> 2sojge8uzabznew6dolq|6b96bac4, idleConnectionTestPeriod -> 300, initialPoolSize -> 3, maxAdministrativeTaskTime -> 0, maxConnectionAge -> 0, maxIdleTime -> 0, maxIdleTimeExcessConnections -> 0, maxPoolSize -> 50, maxStatements -> 2500, maxStatementsPerConnection -> 0, minPoolSize -> 5, nestedDataSource -> com.mchange.v2.c3p0.DriverManagerDataSource@55ae6650 [ description -> null, driverClass -> null, factoryClassLocation -> null, identityToken -> 2sojge8uzabznew6dolq|578b1f8f, jdbcUrl -> jdbc:mysql://nightly-1.ent.cloudera.com:3306/navigatorb5b94558b487d693a56b721a91aa2fa0?useUnicode=true&characterEncoding=UTF-8, properties -> {user=******, password=******, autocommit=true, release_mode=auto} ], preferredTestQuery -> null, propertyCycle -> 0, testConnectionOnCheckin -> false, testConnectionOnCheckout -> false, unreturnedConnectionTimeout -> 0, usesTraditionalReflectiveProxies -> false; userOverrides: {} ], dataSourceName -> null, factoryClassLocation -> null, identityToken -> 2sojge8uzabznew6dolq|73d4d493, numHelperThreads -> 3 ]", "com.mchange.v2.c3p0.WrapperConnectionPoolDataSource@bc23ea6 [ acquireIncrement -> 3, acquireRetryAttempts -> 30, acquireRetryDelay -> 1000, autoCommitOnClose -> false, automaticTestTable -> null, breakAfterAcquireFailure -> false, checkoutTimeout -> 0, connectionCustomizerClassName -> null, connectionTesterClassName -> com.mchange.v2.c3p0.impl.DefaultConnectionTester, debugUnreturnedConnectionStackTraces -> false, factoryClassLocation -> null, forceIgnoreUnresolvedTransactions -> false, identityToken -> 2sojge8uzabznew6dolq|6b96bac4, idleConnectionTestPeriod -> 300, initialPoolSize -> 3, maxAdministrativeTaskTime -> 0, maxConnectionAge -> 0, maxIdleTime -> 0, maxIdleTimeExcessConnections -> 0, maxPoolSize -> 50, maxStatements -> 2500, maxStatementsPerConnection -> 0, minPoolSize -> 5, nestedDataSource -> com.mchange.v2.c3p0.DriverManagerDataSource@55ae6650 [ description -> null, driverClass -> null, factoryClassLocation -> null, identityToken -> 2sojge8uzabznew6dolq|578b1f8f, jdbcUrl -> jdbc:mysql://nightly-1.ent.cloudera.com:3306/navigatorb5b94558b487d693a56b721a91aa2fa0?useUnicode=true&characterEncoding=UTF-8, properties -> {user=******, password=******, autocommit=true, release_mode=auto} ], preferredTestQuery -> null, propertyCycle -> 0, testConnectionOnCheckin -> false, testConnectionOnCheckout -> false, unreturnedConnectionTimeout -> 0, usesTraditionalReflectiveProxies -> false; userOverrides: {} ]" ],
    "AllPooledDataSourcesStringified" : [ "com.mchange.v2.c3p0.PoolBackedDataSource@10e18449 [ connectionPoolDataSource -> com.mchange.v2.c3p0.WrapperConnectionPoolDataSource@bc23ea6 [ acquireIncrement -> 3, acquireRetryAttempts -> 30, acquireRetryDelay -> 1000, autoCommitOnClose -> false, automaticTestTable -> null, breakAfterAcquireFailure -> false, checkoutTimeout -> 0, connectionCustomizerClassName -> null, connectionTesterClassName -> com.mchange.v2.c3p0.impl.DefaultConnectionTester, debugUnreturnedConnectionStackTraces -> false, factoryClassLocation -> null, forceIgnoreUnresolvedTransactions -> false, identityToken -> 2sojge8uzabznew6dolq|6b96bac4, idleConnectionTestPeriod -> 300, initialPoolSize -> 3, maxAdministrativeTaskTime -> 0, maxConnectionAge -> 0, maxIdleTime -> 0, maxIdleTimeExcessConnections -> 0, maxPoolSize -> 50, maxStatements -> 2500, maxStatementsPerConnection -> 0, minPoolSize -> 5, nestedDataSource -> com.mchange.v2.c3p0.DriverManagerDataSource@55ae6650 [ description -> null, driverClass -> null, factoryClassLocation -> null, identityToken -> 2sojge8uzabznew6dolq|578b1f8f, jdbcUrl -> jdbc:mysql://nightly-1.ent.cloudera.com:3306/navigatorb5b94558b487d693a56b721a91aa2fa0?useUnicode=true&characterEncoding=UTF-8, properties -> {user=******, password=******, autocommit=true, release_mode=auto} ], preferredTestQuery -> null, propertyCycle -> 0, testConnectionOnCheckin -> false, testConnectionOnCheckout -> false, unreturnedConnectionTimeout -> 0, usesTraditionalReflectiveProxies -> false; userOverrides: {} ], dataSourceName -> null, factoryClassLocation -> null, identityToken -> 2sojge8uzabznew6dolq|73d4d493, numHelperThreads -> 3 ]" ],
    "C3p0Version" : "0.9.1.1"
  }, {
    "name" : "com.sun.management:type=HotSpotDiagnostic",
    "modelerType" : "sun.management.HotSpotDiagnostic",
    "DiagnosticOptions" : [ {
      "name" : "HeapDumpBeforeFullGC",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "HeapDumpAfterFullGC",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "HeapDumpOnOutOfMemoryError",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "HeapDumpPath",
      "origin" : "DEFAULT",
      "value" : "",
      "writeable" : true
    }, {
      "name" : "CMSAbortablePrecleanWaitMillis",
      "origin" : "DEFAULT",
      "value" : "100",
      "writeable" : true
    }, {
      "name" : "CMSWaitDuration",
      "origin" : "DEFAULT",
      "value" : "2000",
      "writeable" : true
    }, {
      "name" : "PrintGC",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintGCDetails",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintGCDateStamps",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintGCTimeStamps",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintClassHistogramBeforeFullGC",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintClassHistogramAfterFullGC",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintClassHistogram",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintConcurrentLocks",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    } ]
  }, {
    "name" : "com.cloudera.navigator.ipc:type=NavigatorIPC,name=insertion-rate",
    "modelerType" : "com.yammer.metrics.reporting.JmxReporter$Meter",
    "Count" : 408,
    "EventType" : "insertedRecords",
    "RateUnit" : "SECONDS",
    "MeanRate" : 0.0218627888472921,
    "OneMinuteRate" : 0.009188421225056587,
    "FiveMinuteRate" : 0.014748492955889553,
    "FifteenMinuteRate" : 0.008984019505063544
  }, {
    "name" : "com.cloudera.navigator.ipc:type=NavigatorIPC,name=active-write-requests",
    "modelerType" : "com.yammer.metrics.reporting.JmxReporter$Counter",
    "Count" : 0
  }, {
    "name" : "JMImplementation:type=MBeanServerDelegate",
    "modelerType" : "javax.management.MBeanServerDelegate",
    "MBeanServerId" : "nightly-1.ent.cloudera.com_1367933271962",
    "SpecificationName" : "Java Management Extensions",
    "SpecificationVersion" : "1.4",
    "SpecificationVendor" : "Sun Microsystems",
    "ImplementationName" : "JMX",
    "ImplementationVersion" : "1.6.0_31-b04",
    "ImplementationVendor" : "Sun Microsystems"
  } ]
}
"""
